@@ -12,10 +12,10 @@ class Charlier(OrthogonalPolynomialsGenerator):
         mu (int, float or sympy.Symbol): parameter of Chalier Polynomials
     """
 
-    def __init__(self, x, mu):
+    def __init__(self, mu, x=Symbol('x')):
         if not (isinstance(mu, Symbol) or (isinstance(mu, float) and mu > 0)):
             warn("The parameter mu should be a real positive number (float) or a sympy.Symbol.")
-        super().__init__(x, [mu])
+        super().__init__([mu], x)
 
 
     def __str__(self):
