@@ -13,12 +13,12 @@ class Meixner(OrthogonalPolynomialsGenerator):
         c (int, float or sympy.Symbol): second parameter of Meixner Polynomials
     """
 
-    def __init__(self, x, beta, c):
+    def __init__(self, beta, c, x=Symbol('x')):
         if not (isinstance(beta, Symbol) or (isinstance(beta, float) and beta > 0)):
             warn("The parameter beta should be a real positive number (float) or a sympy.Symbol.")
         if not (isinstance(c, Symbol) or (isinstance(c, float) and c > 0 and c < 1)):
             warn("The parameter c should be a real number in ]0,1[ (float) or a sympy.Symbol.")
-        super().__init__(x, [beta, c])
+        super().__init__([beta, c], x)
 
 
     def __str__(self):
